package com.example.demo.product.entity;

import cn.easyes.annotation.HighLight;
import cn.easyes.annotation.IndexField;
import cn.easyes.annotation.IndexId;
import cn.easyes.annotation.IndexName;
import cn.easyes.annotation.rely.Analyzer;
import cn.easyes.annotation.rely.FieldType;
import cn.easyes.annotation.rely.IdType;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 全品类产品主表
 *  product
 */
@IndexName(value ="product",shardsNum = 3,replicasNum = 2)
@Data
public class ProductEntity {
    /**
     * 产品唯一ID
     */
    @IndexId(type = IdType.CUSTOMIZE)
    private Long id;

    /**
     * 类型：1-机票 2-酒店 3-门票 4-车票
     */
    @IndexField(fieldType = FieldType.INTEGER)
    private Integer productType;

    /**
     * 产品标题
     */
    @HighLight(mappingField = "highlightContent")
    @IndexField(fieldType = FieldType.TEXT,analyzer = Analyzer.IK_MAX_WORD,searchAnalyzer = Analyzer.IK_SMART)
    private String title;

    /**
     * 售价
     */
    @IndexField(fieldType = FieldType.DOUBLE)
    private BigDecimal price;

    /**
     * 库存（适用于门票、车票等）
     */
    @IndexField(fieldType = FieldType.INTEGER)
    private Integer stock;

    /**
     * 产品详情描述
     */
    @IndexField(fieldType = FieldType.TEXT)
    private String description;

    /**
     * 封面图地址
     */
    @IndexField(fieldType = FieldType.TEXT)
    private String coverImg;

    /**
     * 创建时间
     */
    @IndexField(fieldType = FieldType.DATE)
    private Date createTime;

    /**
     * 更新时间
     */
    @IndexField(fieldType = FieldType.DATE)
    private Date updateTime;
}