package com.example.demo.product.entity;

import cn.easyes.annotation.HighLight;
import cn.easyes.annotation.IndexField;
import cn.easyes.annotation.IndexId;
import cn.easyes.annotation.IndexName;
import cn.easyes.annotation.rely.Analyzer;
import cn.easyes.annotation.rely.FieldType;
import cn.easyes.annotation.rely.IdType;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;

import java.util.Date;

/**
 * 酒店产品扩展信息表
 *  product_hotel
 */
@IndexName(value ="hotel",shardsNum = 3, replicasNum = 2)
@Data
public class ProductHotelEntity {
    /**
     * 酒店产品ID
     */
    @IndexId(type = IdType.CUSTOMIZE)
    private Long id;

    /**
     * 关联产品主表ID
     */
    @IndexField(fieldType = FieldType.LONG)
    private Long productId;

    /**
     * 酒店名称
     */
    @HighLight(mappingField = "highlightContent")
    @IndexField(fieldType = FieldType.TEXT,analyzer = Analyzer.IK_MAX_WORD,searchAnalyzer = Analyzer.IK_SMART)
    private String hotelName;

    /**
     * 房型（如“标间”“大床房”）
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String roomType;

    /**
     * 酒店地址
     */
    @HighLight(mappingField = "highlightContent")
    @IndexField(fieldType = FieldType.TEXT,analyzer = Analyzer.IK_MAX_WORD,searchAnalyzer = Analyzer.IK_SMART)
    private String address;

    /**
     * 入住时间
     */
    @IndexField(fieldType = FieldType.DATE)
    @JsonFormat(pattern = "HH:mm:ss", timezone = "GMT+8") // 指定格式和时区
    private Date checkinTime;

    /**
     * 退房时间
     */
    @IndexField(fieldType = FieldType.DATE)
    @JsonFormat(pattern = "HH:mm:ss", timezone = "GMT+8") // 指定格式和时区
    private Date checkoutTime;
}