package com.example.demo.product.service.impl;

import cn.easyes.core.biz.EsPageInfo;
import cn.easyes.core.conditions.LambdaEsQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.demo.common.utils.TokenUtils;
import com.example.demo.product.domain.Product;
import com.example.demo.product.entity.ProductEntity;
import com.example.demo.product.esmapper.ProductEsMapper;
import com.example.demo.product.service.ProductService;
import com.example.demo.product.dao.ProductMapper;
import com.example.demo.user.vo.ResultVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
* @author
* @description 针对表【product(全品类产品主表)】的数据库操作Service实现
* @createDate 2025-06-10 20:12:01
*/
@Service
public class ProductServiceImpl extends ServiceImpl<ProductMapper, Product>
    implements ProductService{
    @Autowired
    private ProductEsMapper productEsMapper;

    @Override
    public ResultVo syncDataToEs() {
        //创建索引
        productEsMapper.createIndex();
        List<Product> productList = this.list();
        List<ProductEntity> productEntityList = new ArrayList<>();
        for (Product product : productList) {
            ProductEntity productEntity = new ProductEntity();
            productEntity.setId(product.getId());
            productEntity.setProductType(product.getProductType());
            productEntity.setTitle(product.getTitle());
            productEntity.setPrice(product.getPrice());
            productEntity.setStock(product.getStock());
            productEntity.setDescription(product.getDescription());
            productEntity.setCoverImg(product.getCoverImg());
            productEntity.setCreateTime(product.getCreateTime());
            productEntity.setUpdateTime(product.getUpdateTime());
            productEntityList.add(productEntity);
        }
        productEsMapper.insertBatch(productEntityList);
        return ResultVo.success("数据同步成功");
    }

    @Override
    public ResultVo getProductList(String token) {
        Long userId = TokenUtils.getUserId(token);
        if (userId==null){
            return ResultVo.error(101,"请先登录");
        }
        LambdaEsQueryWrapper<ProductEntity> wrapper = new LambdaEsQueryWrapper<>();
        EsPageInfo<ProductEntity> pageInfo = productEsMapper.pageQuery(wrapper,1,10);
        return ResultVo.success(pageInfo);
    }
}




