package com.example.demo.scenic_spot.entity;

import cn.easyes.annotation.IndexField;
import cn.easyes.annotation.IndexId;
import cn.easyes.annotation.IndexName;
import cn.easyes.annotation.rely.Analyzer;
import cn.easyes.annotation.rely.FieldType;
import cn.easyes.annotation.rely.IdType;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 景点信息表
 *  scenic_spot
 */
@IndexName(value ="scenic_spot",shardsNum = 3,replicasNum = 2)
@Data
public class ScenicSpotEntity {
    /**
     * 景点ID
     */
    @IndexId(type = IdType.CUSTOMIZE)
    private Long id;

    /**
     * 景点名称
     */
    @IndexField(fieldType = FieldType.TEXT,analyzer = Analyzer.IK_MAX_WORD,searchAnalyzer = Analyzer.IK_SMART)
    private String name;

    /**
     * 景点拼音，用于拼音搜索
     */
    @IndexField(fieldType = FieldType.TEXT,analyzer = Analyzer.IK_MAX_WORD,searchAnalyzer = Analyzer.IK_SMART)
    private String pinyin;

    /**
     * 景点描述
     */
    @IndexField(fieldType = FieldType.TEXT,analyzer = Analyzer.IK_MAX_WORD,searchAnalyzer = Analyzer.IK_SMART)
    private String description;

    /**
     * 详细地址
     */
    @IndexField(fieldType = FieldType.TEXT,analyzer = Analyzer.IK_MAX_WORD,searchAnalyzer = Analyzer.IK_SMART)
    private String address;

    /**
     * 所在城市
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String city;

    /**
     * 所在区县
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String district;

    /**
     * 经度（字符串格式）
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String longitudeStr;

    /**
     * 纬度（字符串格式）
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String latitudeStr;

    /**
     * 景点类型
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String category;

    /**
     * 景区等级
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String level;

    /**
     * 封面图片
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String coverImage;

    /**
     * 门票价格
     */
    @IndexField(fieldType = FieldType.DOUBLE)
    private BigDecimal ticketPrice;

    /**
     * 优惠价格
     */
    @IndexField(fieldType = FieldType.DOUBLE)
    private BigDecimal discountPrice;

    /**
     * 开放时间描述
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String openTime;

    /**
     * 营业时间（开始）
     */
    @IndexField(fieldType = FieldType.DATE)
    private Date openTimeStart;

    /**
     * 营业时间（结束）
     */
    @IndexField(fieldType = FieldType.DATE)
    private Date openTimeEnd;

    /**
     * 建议游玩时长（分钟）
     */
    @IndexField(fieldType = FieldType.INTEGER)
    private Integer recommendedTime;

    /**
     * 联系电话
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String contactPhone;

    /**
     * 官方网站
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String website;

    /**
     * 平均评分
     */
    @IndexField(fieldType = FieldType.DOUBLE)
    private BigDecimal avgRating;

    /**
     * 是否热门景点
     */
    @IndexField(fieldType = FieldType.INTEGER)
    private Integer isHot;

    /**
     * 是否推荐景点
     */
    @IndexField(fieldType = FieldType.INTEGER)
    private Integer isRecommended;

    /**
     * 状态
     */
    @IndexField(fieldType = FieldType.KEYWORD)
    private String status;

    /**
     * 景点标签，多个用逗号分隔
     */
    @IndexField(fieldType = FieldType.TEXT, analyzer = Analyzer.IK_MAX_WORD, searchAnalyzer = Analyzer.IK_MAX_WORD)
    private String tags;

    /**
     * 创建人ID
     */
    @IndexField(fieldType = FieldType.LONG)
    private Long createdBy;

    /**
     * 创建时间
     */
    @IndexField(fieldType = FieldType.DATE)
    private Date createdTime;

    /**
     * 更新人ID
     */
    @IndexField(fieldType = FieldType.LONG)
    private Long updatedBy;

    /**
     * 更新时间
     */
    @IndexField(fieldType = FieldType.DATE)
    private Date updatedTime;

    /**
     * 是否删除 0:否 1:是
     */
    @IndexField(fieldType = FieldType.INTEGER)
    private Integer isDeleted;
}